Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(135)

Unified Diff: chromeos/dbus/fake_shill_service_client.h

Issue 31773002: cryptohome: Convet all *Stub classes into Fake* classes (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: address comments Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/fake_shill_profile_client.cc ('k') | chromeos/dbus/fake_shill_service_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/fake_shill_service_client.h
diff --git a/chromeos/dbus/shill_service_client_stub.h b/chromeos/dbus/fake_shill_service_client.h
similarity index 89%
rename from chromeos/dbus/shill_service_client_stub.h
rename to chromeos/dbus/fake_shill_service_client.h
index 810a8ea63db77bea779763a23dd7f6fc025543c8..91000e49b39211fbe367d3815b54743bf813f87b 100644
--- a/chromeos/dbus/shill_service_client_stub.h
+++ b/chromeos/dbus/fake_shill_service_client.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
+// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROMEOS_DBUS_SHILL_SERVICE_CLIENT_STUB_H_
-#define CHROMEOS_DBUS_SHILL_SERVICE_CLIENT_STUB_H_
+#ifndef CHROMEOS_DBUS_FAKE_SHILL_SERVICE_CLIENT_H_
+#define CHROMEOS_DBUS_FAKE_SHILL_SERVICE_CLIENT_H_
#include <map>
#include <string>
@@ -16,13 +16,14 @@
namespace chromeos {
-// A stub implementation of ShillServiceClient. This works in close coordination
-// with ShillManagerClientStub and is not intended to be used independently.
-class ShillServiceClientStub : public ShillServiceClient,
- public ShillServiceClient::TestInterface {
+// A fake implementation of ShillServiceClient. This works in close coordination
+// with FakeShillManagerClient and is not intended to be used independently.
+class CHROMEOS_EXPORT FakeShillServiceClient :
+ public ShillServiceClient,
+ public ShillServiceClient::TestInterface {
public:
- ShillServiceClientStub();
- virtual ~ShillServiceClientStub();
+ FakeShillServiceClient();
+ virtual ~FakeShillServiceClient();
// ShillServiceClient overrides
virtual void Init(dbus::Bus* bus) OVERRIDE;
@@ -124,11 +125,11 @@ class ShillServiceClientStub : public ShillServiceClient,
// Note: This should remain the last member so it'll be destroyed and
// invalidate its weak pointers before any other members are destroyed.
- base::WeakPtrFactory<ShillServiceClientStub> weak_ptr_factory_;
+ base::WeakPtrFactory<FakeShillServiceClient> weak_ptr_factory_;
- DISALLOW_COPY_AND_ASSIGN(ShillServiceClientStub);
+ DISALLOW_COPY_AND_ASSIGN(FakeShillServiceClient);
};
} // namespace chromeos
-#endif // CHROMEOS_DBUS_SHILL_SERVICE_CLIENT_STUB_H_
+#endif // CHROMEOS_DBUS_FAKE_SHILL_SERVICE_CLIENT_H_
« no previous file with comments | « chromeos/dbus/fake_shill_profile_client.cc ('k') | chromeos/dbus/fake_shill_service_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698